pub trait PhfEq<B>where
B: ?Sized,{
// Required method
fn phf_eq(&self, other: &B) -> bool;
}Expand description
Trait for comparing stored PHF keys with runtime lookup keys.
Lookup keys must hash the same way as the stored key they compare equal to.
Most borrowed key forms use the blanket implementation based on
PhfBorrow. Tuples are implemented separately so references inside a
tuple can use shorter lifetimes at lookup time. Tuple impls are provided up
to 12 elements.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".